@@ -416,6 +416,98 @@ pub fn get_args(version: &str) -> ArgMatches {
                         .value_name("STRING"),
                 ),
         )
+        .subcommand(
+            App::new("rename")
+            .about("Batch renaming sequence IDs in multiple alignments")
+                .arg(
+                    Arg::with_name("dir")
+                    .short("d")
+                    .long("dir")
+                    .help("Inputs dir with alignment files")
+                    .takes_value(true)
+                    .value_name("PATH"),
+                )
+                .arg(
+                    Arg::with_name("wildcard")
+                            .short("c")
+                            .long("wcard")
+                            .help("Uses wildcard as an input")
+                            .takes_value(true)
+                            .multiple(true)
+                            .required_unless("input")
+                            .conflicts_with_all(&["input", "dir"])
+                            .value_name("WILDCARD"),
+                )
+                .arg(
+                    Arg::with_name("input-format")
+                        .short("f")
+                        .long("input-format")
+                        .help("Sets input format")
+                        .takes_value(true)
+                        .required(true)
+                        .value_name("SEQ-FORMAT")
+                        .default_value("auto")
+                        .possible_values(&[
+                            "auto",
+                            "fasta",
+                            "nexus",
+                            "phylip",
+                        ]),
+                )
+                .arg(
+                    Arg::with_name("output")
+                        .short("o")
+                        .long("output")
+                        .help("Uses a costume output filename")
+                        .takes_value(true)
+                        .required(true)
+                        .default_value("SEGUL-rename")
+                        .value_name("STRING"),
+                )
+                .arg(
+                    Arg::with_name("output-format")
+                        .short("F")
+                        .long("output-format")
+                        .help("Sets target output format")
+                        .takes_value(true)
+                        .default_value("nexus")
+                        .value_name("SEQ-FORMAT")
+                        .possible_values(&[
+                            "nexus",
+                            "phylip",
+                            "fasta",
+                            "fasta-int",
+                            "nexus-int",
+                            "phylip-int",
+                        ]),
+                )
+                .arg(
+                    Arg::with_name("datatype")
+                        .long("datatype")
+                        .help("Sets data type")
+                        .takes_value(true)
+                        .required(true)
+                        .value_name("DATATYPE")
+                        .default_value("dna")
+                        .possible_values(&["dna", "aa", "ignore"]),
+                )
+                .arg(
+                    Arg::with_name("names")
+                        .short("n")
+                        .long("names")
+                        .help("Inputs IDs to rename")
+                        .takes_value(true)
+                        .required(true)
+                        .value_name("PATH"),
+
+                )
+                .arg(
+                    Arg::with_name("dry-run")
+                        .long("dry-run")
+                        .help("Check if the program can parse the input ids correctly")
+                        .takes_value(false),
+                ),
+        )
         .subcommand(
             App::new("summary")
                 .about("Gets alignment summary stats")
@@ -727,8 +819,6 @@ pub fn get_args(version: &str) -> ArgMatches {
                         .help("Show supported NCBI Genetic Code tables")
                         .takes_value(false)
                 )
-                
-            
         )
         .get_matches()
 }
